==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/IO/HGetPosn.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_IO_46hGetPosnC_35	((void*)startLabel+8)
#define CT_v227	((void*)startLabel+36)
#define F0_IO_46hGetPosnC_35	((void*)startLabel+44)
#define FN_IO_46hGetPosnC	((void*)startLabel+56)
#define CT_v229	((void*)startLabel+80)
#define CF_IO_46hGetPosnC	((void*)startLabel+88)
#define CT_v231	((void*)startLabel+144)
#define FN_LAMBDA224	((void*)startLabel+184)
#define v232	((void*)startLabel+210)
#define CT_v235	((void*)startLabel+256)
#define F0_LAMBDA224	((void*)startLabel+264)
#define FN_LAMBDA223	((void*)startLabel+320)
#define CT_v237	((void*)startLabel+356)
#define F0_LAMBDA223	((void*)startLabel+364)
#define FN_LAMBDA222	((void*)startLabel+384)
#define CT_v239	((void*)startLabel+428)
#define F0_LAMBDA222	((void*)startLabel+436)
#define FN_LAMBDA221	((void*)startLabel+456)
#define CT_v242	((void*)startLabel+488)
#define CF_LAMBDA221	((void*)startLabel+496)
#define ST_v230	((void*)startLabel+500)
#define ST_v234	((void*)startLabel+512)
#define ST_v238	((void*)startLabel+530)
#define ST_v240	((void*)startLabel+548)
#define ST_v236	((void*)startLabel+566)
#define ST_v228	((void*)startLabel+584)
#define ST_v226	((void*)startLabel+597)
#define ST_v241	((void*)startLabel+611)
extern Node TM_IO[];
void FR_IO_46hGetPosnC_35(void);
extern Node TM_IO[];
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node TM_IO[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_IO[];
extern Node FN_Prelude_46Eq_46NHC_46FFI_46Ptr_46_61_61[];
extern Node CF_NHC_46FFI_46nullPtr[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node CF_NHC_46FFI_46getErrNo[];
extern Node FN_NHC_46FFI_46newForeignPtr[];
extern Node FN_NHC_46FFI_46free[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node TMSUB_IO[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node TMSUB_IO[];
extern Node FN_NHC_46FFI_46throwIOError[];
extern Node TMSUB_IO[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v227)
,	/* FN_IO_46hGetPosnC_35: (byte 0) */
  useLabel(TM_IO)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_IO_46hGetPosnC_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v226)
,	/* CT_v227: (byte 0) */
  HW(0,1)
, 0
,	/* F0_IO_46hGetPosnC_35: (byte 0) */
  CAPTAG(useLabel(FN_IO_46hGetPosnC_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v229)
,	/* FN_IO_46hGetPosnC: (byte 0) */
  useLabel(TM_IO)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v228)
,	/* CT_v229: (byte 0) */
  HW(2,0)
, 0
,	/* CF_IO_46hGetPosnC: (byte 0) */
  VAPTAG(useLabel(FN_IO_46hGetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_IO_46hGetPosnC_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v231)
,};
Node FN_IO_46hGetPosn[] = {
  useLabel(TM_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG,1,HEAP_CVAL_I5)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(6,HEAP_OFF_N1,6,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v230)
,	/* CT_v231: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_IO_46hGetPosn[] = {
  CAPTAG(useLabel(FN_IO_46hGetPosn),1)
, VAPTAG(useLabel(FN_IO_46hGetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA224),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v235)
,	/* FN_LAMBDA224: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(2,HEAP_CVAL_I4,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,13,0,HEAP_CVAL_I5)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(6,HEAP_CVAL_P1,7,HEAP_OFF_N1)
,	/* v232: (byte 2) */
  bytes2word(4,RETURN_EVAL,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_P1,10)
, bytes2word(HEAP_OFF_N1,2,HEAP_ARG,2)
, bytes2word(HEAP_CVAL_P1,11,HEAP_OFF_N1,6)
, bytes2word(HEAP_ARG,2,HEAP_OFF_N1,6)
, bytes2word(HEAP_CVAL_P1,12,HEAP_ARG,1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(7,HEAP_OFF_N1,4,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 130010
, useLabel(ST_v234)
,	/* CT_v235: (byte 0) */
  HW(10,2)
, 0
,	/* F0_LAMBDA224: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA224),2)
, VAPTAG(useLabel(FN_Prelude_46Eq_46NHC_46FFI_46Ptr_46_61_61))
, useLabel(CF_NHC_46FFI_46nullPtr)
, CAPTAG(useLabel(FN_LAMBDA222),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_NHC_46FFI_46getErrNo)
, VAPTAG(useLabel(FN_NHC_46FFI_46newForeignPtr))
, VAPTAG(useLabel(FN_NHC_46FFI_46free))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA223),1)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v237)
,	/* FN_LAMBDA223: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_IN3,HEAP_ARG_ARG,1)
, bytes2word(2,PUSH_HEAP,HEAP_CVAL_I3,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,2,0)
, 180014
, useLabel(ST_v236)
,	/* CT_v237: (byte 0) */
  HW(1,2)
, 0
,	/* F0_LAMBDA223: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA223),2)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v239)
,	/* FN_LAMBDA222: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_IN3,HEAP_CVAL_N1)
, bytes2word(4,HEAP_ARG,1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,5,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,5,HEAP_ARG)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, CONSTR(1,1,0)
, CONSTR(0,0,0)
, 150018
, useLabel(ST_v238)
,	/* CT_v239: (byte 0) */
  HW(2,2)
, 0
,	/* F0_LAMBDA222: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA222),2)
, VAPTAG(useLabel(FN_LAMBDA221))
, VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
, bytes2word(0,0,0,0)
, useLabel(CT_v242)
,	/* FN_LAMBDA221: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v241)
, 160022
, useLabel(ST_v240)
,	/* CT_v242: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA221: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA221))
,	/* ST_v230: (byte 0) */
  bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
,	/* ST_v234: (byte 4) */
  bytes2word(111,115,110,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,51,58,49)
,	/* ST_v238: (byte 2) */
  bytes2word(48,0,73,79)
, bytes2word(46,104,71,101)
, bytes2word(116,80,111,115)
, bytes2word(110,58,49,53)
,	/* ST_v240: (byte 4) */
  bytes2word(58,49,56,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,54,58,50)
,	/* ST_v236: (byte 2) */
  bytes2word(50,0,73,79)
, bytes2word(46,104,71,101)
, bytes2word(116,80,111,115)
, bytes2word(110,58,49,56)
,	/* ST_v228: (byte 4) */
  bytes2word(58,49,52,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,67)
,	/* ST_v226: (byte 1) */
  bytes2word(0,73,79,46)
, bytes2word(104,71,101,116)
, bytes2word(80,111,115,110)
,	/* ST_v241: (byte 3) */
  bytes2word(67,35,0,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hGetPosnC" IO.hGetPosnC# 1 :: FFI.ForeignObj -> FFI.Ptr */
extern void* hGetPosnC(void*);
#ifdef PROFILE
static SInfo pf_hGetPosnC = {"IO","IO.hGetPosnC#","FFI.Ptr"};
#endif
C_HEADER(FR_IO_46hGetPosnC_35) {
  NodePtr nodeptr;
  void* result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hGetPosnC(arg1);

  nodeptr = nhc_mkInt((int)result);
  INIT_PROFINFO(nodeptr,&pf_hGetPosnC);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/IO/HGetPosn.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_IO_46hGetPosnC_35	((void*)startLabel+8)
#define CT_v241	((void*)startLabel+36)
#define F0_IO_46hGetPosnC_35	((void*)startLabel+44)
#define FN_IO_46hGetPosnC	((void*)startLabel+56)
#define CT_v243	((void*)startLabel+80)
#define CF_IO_46hGetPosnC	((void*)startLabel+88)
#define CT_v245	((void*)startLabel+144)
#define FN_LAMBDA238	((void*)startLabel+184)
#define v246	((void*)startLabel+210)
#define CT_v249	((void*)startLabel+248)
#define F0_LAMBDA238	((void*)startLabel+256)
#define FN_LAMBDA237	((void*)startLabel+308)
#define CT_v251	((void*)startLabel+344)
#define F0_LAMBDA237	((void*)startLabel+352)
#define FN_LAMBDA236	((void*)startLabel+372)
#define CT_v253	((void*)startLabel+416)
#define F0_LAMBDA236	((void*)startLabel+424)
#define FN_LAMBDA235	((void*)startLabel+444)
#define CT_v256	((void*)startLabel+476)
#define CF_LAMBDA235	((void*)startLabel+484)
#define ST_v244	((void*)startLabel+488)
#define ST_v248	((void*)startLabel+500)
#define ST_v252	((void*)startLabel+524)
#define ST_v254	((void*)startLabel+548)
#define ST_v250	((void*)startLabel+572)
#define ST_v242	((void*)startLabel+596)
#define ST_v240	((void*)startLabel+609)
#define ST_v255	((void*)startLabel+623)
extern Node TM_IO[];
void FR_IO_46hGetPosnC_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_IO[];
extern Node FN_Prelude_46Eq_46NHC_46FFI_46Ptr_46_61_61[];
extern Node CF_NHC_46FFI_46nullPtr[];
extern Node CF_NHC_46FFI_46getErrNo[];
extern Node FN_NHC_46FFI_46newForeignPtr[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node CF_NHC_46FFI_46finalizerFree[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node FN_NHC_46FFI_46throwIOError[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v241)
,	/* FN_IO_46hGetPosnC_35: (byte 0) */
  useLabel(TM_IO)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_IO_46hGetPosnC_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70001
, useLabel(ST_v240)
,	/* CT_v241: (byte 0) */
  HW(0,1)
, 0
,	/* F0_IO_46hGetPosnC_35: (byte 0) */
  CAPTAG(useLabel(FN_IO_46hGetPosnC_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v243)
,	/* FN_IO_46hGetPosnC: (byte 0) */
  useLabel(TM_IO)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 70001
, useLabel(ST_v242)
,	/* CT_v243: (byte 0) */
  HW(2,0)
, 0
,	/* CF_IO_46hGetPosnC: (byte 0) */
  VAPTAG(useLabel(FN_IO_46hGetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_IO_46hGetPosnC_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v245)
,};
Node FN_IO_46hGetPosn[] = {
  useLabel(TM_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG,1,HEAP_CVAL_I5)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(6,HEAP_OFF_N1,6,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 100001
, useLabel(ST_v244)
,	/* CT_v245: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_IO_46hGetPosn[] = {
  CAPTAG(useLabel(FN_IO_46hGetPosn),1)
, VAPTAG(useLabel(FN_IO_46hGetPosnC))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA238),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v249)
,	/* FN_LAMBDA238: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(2,HEAP_CVAL_I4,EVAL,NEEDHEAP_I32)
, bytes2word(JUMPFALSE,13,0,HEAP_CVAL_I5)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(6,HEAP_CVAL_P1,7,HEAP_OFF_N1)
,	/* v246: (byte 2) */
  bytes2word(4,RETURN_EVAL,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_P1,9,HEAP_OFF_N1,2)
, bytes2word(HEAP_CVAL_P1,10,HEAP_ARG,2)
, bytes2word(HEAP_CVAL_P1,11,HEAP_ARG,1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(7,HEAP_OFF_N1,4,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 110010
, useLabel(ST_v248)
,	/* CT_v249: (byte 0) */
  HW(9,2)
, 0
,	/* F0_LAMBDA238: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA238),2)
, VAPTAG(useLabel(FN_Prelude_46Eq_46NHC_46FFI_46Ptr_46_61_61))
, useLabel(CF_NHC_46FFI_46nullPtr)
, CAPTAG(useLabel(FN_LAMBDA236),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_NHC_46FFI_46getErrNo)
, VAPTAG(useLabel(FN_NHC_46FFI_46newForeignPtr))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, useLabel(CF_NHC_46FFI_46finalizerFree)
, CAPTAG(useLabel(FN_LAMBDA237),1)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v251)
,	/* FN_LAMBDA237: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_IN3,HEAP_ARG_ARG,1)
, bytes2word(2,PUSH_HEAP,HEAP_CVAL_I3,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 0
, CONSTR(0,2,0)
, 160014
, useLabel(ST_v250)
,	/* CT_v251: (byte 0) */
  HW(1,2)
, 0
,	/* F0_LAMBDA237: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA237),2)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v253)
,	/* FN_LAMBDA236: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_IN3,HEAP_CVAL_N1)
, bytes2word(4,HEAP_ARG,1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,5,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,5,HEAP_ARG)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, CONSTR(1,1,0)
, CONSTR(0,0,0)
, 130018
, useLabel(ST_v252)
,	/* CT_v253: (byte 0) */
  HW(2,2)
, 0
,	/* F0_LAMBDA236: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA236),2)
, VAPTAG(useLabel(FN_LAMBDA235))
, VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
, bytes2word(0,0,0,0)
, useLabel(CT_v256)
,	/* FN_LAMBDA235: (byte 0) */
  useLabel(TMSUB_IO)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v255)
, 140022
, useLabel(ST_v254)
,	/* CT_v256: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA235: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA235))
,	/* ST_v244: (byte 0) */
  bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
,	/* ST_v248: (byte 4) */
  bytes2word(111,115,110,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,49,58,49)
, bytes2word(48,45,49,49)
,	/* ST_v252: (byte 4) */
  bytes2word(58,50,48,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,51,58,49)
, bytes2word(56,45,49,51)
,	/* ST_v254: (byte 4) */
  bytes2word(58,50,53,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,52,58,50)
, bytes2word(50,45,49,52)
,	/* ST_v250: (byte 4) */
  bytes2word(58,51,49,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,58)
, bytes2word(49,54,58,49)
, bytes2word(52,45,49,54)
,	/* ST_v242: (byte 4) */
  bytes2word(58,52,50,0)
, bytes2word(73,79,46,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,67)
,	/* ST_v240: (byte 1) */
  bytes2word(0,73,79,46)
, bytes2word(104,71,101,116)
, bytes2word(80,111,115,110)
,	/* ST_v255: (byte 3) */
  bytes2word(67,35,0,104)
, bytes2word(71,101,116,80)
, bytes2word(111,115,110,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hGetPosnC" IO.hGetPosnC# 1 :: FFI.ForeignObj -> FFI.Ptr */
extern void* hGetPosnC(void*);
#ifdef PROFILE
static SInfo pf_IO_46hGetPosnC_35 = {"IO","IO.hGetPosnC#","FFI.Ptr"};
#endif
C_HEADER(FR_IO_46hGetPosnC_35) {
  NodePtr nodeptr;
  void* result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hGetPosnC(arg1);

  nodeptr = nhc_mkInt((int)result);
  INIT_PROFINFO(nodeptr,&pf_IO_46hGetPosnC_35);
  C_RETURN(nodeptr);
}
